==> haskell-aeson-compat-0.3.0.0-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-aeson-compat/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.0.0
id: aeson-compat-0.3.0.0-3ffd414d5f44f5e3743b6d6d8677523a
key: aeson_HZ5bicL9EiICRC6MZ3NuHN
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Aeson.Compat
hidden-modules: Data.Aeson.Compat.Time
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.0.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.0.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-compat-0.3.0.0
hs-libraries: HSaeson-compat-0.3.0.0-HZ5bicL9EiICRC6MZ3NuHN
depends:
    aeson-0.10.0.0-b63a88a6e7bf231c11601ff561c0eb0d
    attoparsec-0.13.0.1-57451b44323b331c08be1b712bdc3810
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    hashable-1.2.4.0-44b2533f61c94bc76cb2b27e15566721
    scientific-0.3.4.4-2c552cd0c6d8817341c76144fa370151
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    unordered-containers-0.2.6.0-08e36bb27daebf8e082345cc5a0772e7
    vector-0.11.0.0-c9b9eff80d809aeb097685ce86af03c4
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-compat-0.3.0.0-7-armv7h.pkg.tar.xz: usr/share/haskell/haskell-aeson-compat/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.0.0
id: aeson-compat-0.3.0.0-a20a161a51c55c8ab6017f045ab6c3e9
key: aeson_G4kDUECtpuKJHDAeY6OyCk
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Aeson.Compat
hidden-modules: Data.Aeson.Compat.Time
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.0.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.0.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-compat-0.3.0.0
hs-libraries: HSaeson-compat-0.3.0.0-G4kDUECtpuKJHDAeY6OyCk
depends:
    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
